@@ -22,9 +22,11 @@ class Network3Medusa():
         raw_json=self.output.stdout.decode('utf-8')
         if 'eth_admin_fec_state' in raw_json:
             json_dict = json.loads(raw_json)
-            for interface in enumerate(json_dict):
-                if interface == 0:
+            first = True
+            for interface in json_dict:
+                if first:
                     print("first")
+                    first = False
                     raw_json=interface
                     self.add_file_to_hedera(raw_json)
                 else:
